import type { ButtonProps, TooltipProps } from 'antd';
import type { CSSProperties } from 'react';
/**
 * @title 动作图标属性
 * @description 继承自 `Button` 组件所有属性，除了 `title`, `type` 和 `size`
 */
export interface ActionIconProps extends Omit<ButtonProps, 'title' | 'size'> {
    /**
     * @title 鼠标类型
     */
    cursor?: CSSProperties['cursor'];
    /**
     * @title 动作提示
     */
    title?: TooltipProps['title'];
    /**
     * @title 提示位置
     */
    placement?: TooltipProps['placement'];
    /**
     * @title 图标
     */
    icon: ButtonProps['icon'];
    /**
     * @title 点击回调
     */
    onClick?: ButtonProps['onClick'];
    /**
     * @title 图标尺寸
     */
    size?: 'default' | 'large' | number;
    /**
     * @description 鼠标移入时候的延迟tooltip时间，默认 0.5
     * @default 0.5
     */
    tooltipDelay?: number;
    /**
     * @description 是否展示小箭头，默认不展示
     * @default false
     */
    arrow?: boolean;
}
declare const ActionIcon: (props: ActionIconProps) => import("react/jsx-runtime").JSX.Element;
export default ActionIcon;
