import type { NumberSize, Size } from 're-resizable';
import type { CSSProperties, FC, ReactNode } from 'react';
import type { Props as RndProps } from 'react-rnd';
export interface FloatProps {
    /**
     * 位置，
     * 使用固定模式或者浮动窗口
     */
    mode?: 'fixed' | 'float';
    /**
     * 面板的朝向，默认是 左右模式
     * @default horizontal
     */
    direction?: 'vertical' | 'horizontal';
    /**
     * 最小宽度
     */
    minWidth?: number;
    /**
     * 最小高度
     */
    minHeight?: number;
    /**
     * 最大宽度
     */
    maxWidth?: number;
    /**
     * 最大高度
     */
    maxHeight?: number;
    /**
     * 控制可缩放区域
     */
    resize?: RndProps['enableResizing'];
    /**
     * 面板尺寸
     *
     */
    size?: Partial<Size>;
    onSizeChange?: (delta: NumberSize, size?: Size) => void;
    /**
     * 当用户在拖拽过程中触发
     * @param delta
     * @param size
     */
    onSizeDragging?: (delta: NumberSize, size?: Size) => void;
    canResizing?: boolean;
    /**
     * 面板位置
     * 受控模式
     */
    position?: RndProps['position'];
    /**
     * 面板默认尺寸
     * 固定模式下： width 320px height 100%
     * 浮动模式下：width 320px height 400px
     */
    defaultSize?: Partial<Size>;
    /**
     * 面板默认位置悬浮模式下有效
     * @default [100,100]
     */
    defaultPosition?: RndProps['position'];
    /**
     * 位置变更回调
     */
    onPositionChange?: (position: RndProps['position']) => void;
    /**
     * 样式
     */
    style?: CSSProperties;
    /**
     * 类名
     */
    className?: string;
    /**
     * 内容
     */
    children: ReactNode;
}
export declare const FloatMode: FC<FloatProps>;
