import { Viewport } from 'reactflow';
import { AwarenessPublicAction } from "../store/slices/awareness";
import { CanvasPublicAction } from "../store/slices/canvas";
import { ConfigPublicAction } from "../store/slices/config";
import { ConfigPanelPublicAction } from "../store/slices/configPanel";
import { GeneralPublicAction } from "../store/slices/general";
import { AwarenessEditor } from '../store';
/**
 * ProBuilder 实例对象
 * @template Config - 配置信息的类型
 * @template Props - 组件属性的类型
 */
export interface ProBuilderInstance<Config = any, Props = any> extends CanvasPublicAction, ConfigPanelPublicAction, ConfigPublicAction, GeneralPublicAction, AwarenessPublicAction {
    /**
     * 获取编辑器的 Awareness 对象
     * @returns {AwarenessEditor} - 编辑器的 Awareness 对象
     */
    getEditorAwareness: () => AwarenessEditor;
    /**
     * 获取当前视口信息
     * @returns {Viewport} - 当前视口信息
     */
    getViewport: () => Viewport;
    /**
     * 获取配置信息
     * @returns {Config} - 配置信息
     */
    getConfig: () => Config;
    /**
     * 获取组件属性
     * @returns {Props} - 组件属性
     */
    getProps: () => Props;
}
export declare const useProBuilder: <T>() => ProBuilderInstance<T, any>;
