import { arrayMove } from '@dnd-kit/sortable';
import { produce } from 'immer';
import { getUUID } from "../utils";
export var keyManagerReducer = function keyManagerReducer(value, payload) {
  switch (payload.type) {
    case 'moveItem':
      var activeIndex = payload.activeIndex,
        overIndex = payload.overIndex;
      if (activeIndex === overIndex) return;
      if (activeIndex < 0 || activeIndex >= value.length || overIndex < 0 || overIndex >= value.length) {
        return;
      }
      return produce(value, function (draft) {
        var sortedItems = arrayMove(draft, activeIndex, overIndex);
        return sortedItems;
      });
    case 'removeItem':
      var indexSet = new Set(Array.isArray(payload.index) ? payload.index : [payload.index]);
      if (indexSet.size <= 0) {
        return;
      }
      return produce(value, function (draft) {
        var sortedItems = draft.filter(function (_, valueIndex) {
          return !indexSet.has(valueIndex);
        });
        return sortedItems;
      });
    case 'addItem':
      var _payload$index = payload.index,
        index = _payload$index === void 0 ? value.length : _payload$index;
      return produce(value, function (draft) {
        draft.splice(index, 0, getUUID(index));
        return draft;
      });
    case 'updateItem':
      return produce(value, function (draft) {
        return draft;
      });
  }
};