import { PublicSortableTreeStore } from '../store/store';
import { FlattenNode, TreeData, UniqueIdentifier } from '../types';
/**
 * SortableTree 实例对象
 * @template T 节点数据类型
 */
export interface SortableTreeInstance<T = any> extends PublicSortableTreeStore {
    /**
     * 获取当前激活节点的 id
     * @returns 当前激活节点的 id
     */
    getActiveId: () => UniqueIdentifier;
    /**
     * 获取当前选中节点的 id 数组
     * @returns 当前选中节点的 id 数组
     */
    getSelectedIds: () => UniqueIdentifier[];
    /**
     * 获取当前树的数据
     * @returns 当前树的数据
     */
    getTreeData: () => TreeData<T>;
    /**
     * 获取当前树的扁平化数据
     * @returns 当前树的扁平化数据
     */
    getFlattenData: () => FlattenNode<T>[];
}
export declare const useSortableTree: <T>() => SortableTreeInstance<T>;
